@@ -22,6 +22,9 @@
 #include "oxygenscrolledwindowdata.h"
 #include "../oxygengtkutils.h"
 #include "../config.h"
+#include "../oxygencairocontext.h"
+#include "oxygenanimations.h"
+#include "../oxygenstyle.h"
 
 #include <cassert>
 #include <iostream>
@@ -138,7 +141,6 @@ namespace Oxygen
             // allocate new Hover data
             ChildData data;
             data._destroyId.connect( G_OBJECT(widget), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-            data._styleChangeId.connect( G_OBJECT(widget), "style-set", G_CALLBACK( childStyleChangeNotifyEvent ), this );
             data._enterId.connect( G_OBJECT(widget), "enter-notify-event", G_CALLBACK( enterNotifyEvent ), this );
             data._leaveId.connect( G_OBJECT(widget), "leave-notify-event", G_CALLBACK( leaveNotifyEvent ), this );
             data._focusInId.connect( G_OBJECT(widget), "focus-in-event", G_CALLBACK( focusInNotifyEvent ), this );
@@ -206,7 +208,6 @@ namespace Oxygen
         #endif
 
         _destroyId.disconnect();
-        _styleChangeId.disconnect();
         _enterId.disconnect();
         _leaveId.disconnect();
         _focusInId.disconnect();
@@ -229,10 +230,6 @@ namespace Oxygen
         return FALSE;
     }
 
-    //____________________________________________________________________________________________
-    void ScrolledWindowData::childStyleChangeNotifyEvent( GtkWidget* widget, GtkStyle*, gpointer data )
-    { static_cast<ScrolledWindowData*>(data)->unregisterChild( widget ); }
-
     //________________________________________________________________________________
     gboolean ScrolledWindowData::enterNotifyEvent( GtkWidget* widget, GdkEventCrossing* event, gpointer data )
     {
